using System;
using Server;
using Server.Items;
using Server.Mobiles;

namespace Server.Misc
{
	public class CorpseCarving
	{
		public static void Initialize()
		{
			EventSink.CorpseCarved += new CorpseCarvedEventHandler( EventSink_CorpseCarved );
		}

		public static void EventSink_CorpseCarved( CorpseCarvedEventArgs e )
		{
			Corpse corpse = e.Corpse;
			Mobile from = e.From;
			Mobile dead = corpse.Owner;

			if ( corpse.Carved || dead == null )
			{
				from.SendLocalizedMessage( 500485 ); // You see nothing useful to carve from the corpse.
			}
			else if ( dead.Body.IsHuman )
			{
				new Blood( 0x122D ).MoveToWorld( corpse.Location, corpse.Map );

				new Torso().MoveToWorld( corpse.Location, corpse.Map );
				new LeftLeg().MoveToWorld( corpse.Location, corpse.Map );
				new LeftArm().MoveToWorld( corpse.Location, corpse.Map );
				new RightLeg().MoveToWorld( corpse.Location, corpse.Map );
				new RightArm().MoveToWorld( corpse.Location, corpse.Map );
				new Head( String.Format( "the head of {0}", dead.Name ) ).MoveToWorld( corpse.Location, corpse.Map );

				corpse.Carved = true;

				corpse.ProcessDelta();
				corpse.SendRemovePacket();
				corpse.ItemID = Utility.Random( 0xECA, 9 ); // bone graphic
				corpse.Hue = 0;
				corpse.ProcessDelta();

				if ( Notoriety.Compute( from, corpse ) == Notoriety.Innocent )
					from.CriminalAction( true );
			}
			else if ( dead is BaseCreature )
			{
				((BaseCreature)dead).OnCarve( from, corpse );
			}
			else
			{
				from.SendLocalizedMessage( 500485 ); // You see nothing useful to carve from the corpse.
			}
		}
	}
}