using System;
using Server.Items;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	[CorpseName( "a wyvern corpse" )]
	public class Wyvern : BaseCreature
	{
		[Constructable]
		public Wyvern () : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "a wyvern";
			Body = 62;
			BaseSoundID = 362;

			SetStr( 202, 240 );
			SetDex( 153, 172 );
			SetInt( 51, 90 );

			SetHits( 125, 141 );

			SetDamage( 8, 19 );

			SetSkill( SkillName.Poisoning, 60.1, 80.0 );
			SetSkill( SkillName.MagicResist, 65.1, 80.0 );
			SetSkill( SkillName.Tactics, 65.1, 90.0 );
			SetSkill( SkillName.Wrestling, 65.1, 80.0 );

			Fame = 4000;
			Karma = -4000;

			VirtualArmor = 40;

			// Temporary Switches Until RandomScroll Class is made
			switch ( Utility.Random( 6 ))
			{
				case 0: PackItem( new CreateFoodScroll() ); break;
				case 1: PackItem( new HarmScroll() ); break;
				case 2: PackItem( new TeleportScroll() ); break;
				case 3: PackItem( new RecallScroll() ); break;
				case 4: PackItem( new MindBlastScroll() ); break;
				case 5: PackItem( new DispelScroll() ); break;
			}

			switch ( Utility.Random( 6 ))
			{
				case 0: PackItem( new NightSightScroll() ); break;
				case 1: PackItem( new StrengthScroll() ); break;
				case 2: PackItem( new UnlockScroll() ); break;
				case 3: PackItem( new GreaterHealScroll() ); break;
				case 4: PackItem( new IncognitoScroll() ); break;
				case 5: PackItem( new MarkScroll() ); break;
			}

			PackGold( 100, 250 );
			PackItem( RandomScroll.CreateScroll( 1, 7 ) );
			PackItem( RandomScroll.CreateScroll( 1, 6 ) );
		}

		public override Poison PoisonImmune{ get{ return Poison.Deadly; } }
		public override Poison HitPoison{ get{ return Poison.Deadly; } }
		public override int TreasureMapLevel{ get{ return 2; } }

		public Wyvern( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}